@@ -374,7 +374,7 @@ class DevOpsGuruClient(BaseClient):
     def list_monitored_resources(
         self,
         *,
-        Filters: ListMonitoredResourcesFiltersTypeDef,
+        Filters: ListMonitoredResourcesFiltersTypeDef = ...,
         MaxResults: int = ...,
         NextToken: str = ...
     ) -> ListMonitoredResourcesResponseTypeDef:
