@@ -48,6 +48,7 @@ __all__ = (
     "ListRecommendationsPaginatorName",
     "LocaleType",
     "LogAnomalyTypeType",
+    "NotificationMessageTypeType",
     "OptInStatusType",
     "OrganizationResourceCollectionTypeType",
     "ResourceCollectionTypeType",
@@ -126,13 +127,44 @@ LogAnomalyTypeType = Literal[
     "NUMERICAL_NAN",
     "NUMERICAL_POINT",
 ]
+NotificationMessageTypeType = Literal[
+    "CLOSED_INSIGHT", "NEW_ASSOCIATION", "NEW_INSIGHT", "NEW_RECOMMENDATION", "SEVERITY_UPGRADED"
+]
 OptInStatusType = Literal["DISABLED", "ENABLED"]
 OrganizationResourceCollectionTypeType = Literal[
     "AWS_ACCOUNT", "AWS_CLOUD_FORMATION", "AWS_SERVICE", "AWS_TAGS"
 ]
 ResourceCollectionTypeType = Literal["AWS_CLOUD_FORMATION", "AWS_SERVICE", "AWS_TAGS"]
 ResourcePermissionType = Literal["FULL_PERMISSION", "MISSING_PERMISSION"]
-ResourceTypeFilterType = Literal["LOG_GROUPS"]
+ResourceTypeFilterType = Literal[
+    "CLOUDFRONT_DISTRIBUTION",
+    "DYNAMODB_TABLE",
+    "EC2_NAT_GATEWAY",
+    "ECS_CLUSTER",
+    "ECS_SERVICE",
+    "EKS_CLUSTER",
+    "ELASTICACHE_CACHE_CLUSTER",
+    "ELASTICSEARCH_DOMAIN",
+    "ELASTIC_BEANSTALK_ENVIRONMENT",
+    "ELASTIC_LOAD_BALANCER_LOAD_BALANCER",
+    "ELASTIC_LOAD_BALANCING_V2_LOAD_BALANCER",
+    "ELASTIC_LOAD_BALANCING_V2_TARGET_GROUP",
+    "KINESIS_STREAM",
+    "LAMBDA_FUNCTION",
+    "LOG_GROUPS",
+    "OPEN_SEARCH_SERVICE_DOMAIN",
+    "RDS_DB_CLUSTER",
+    "RDS_DB_INSTANCE",
+    "REDSHIFT_CLUSTER",
+    "ROUTE53_HEALTH_CHECK",
+    "ROUTE53_HOSTED_ZONE",
+    "S3_BUCKET",
+    "SAGEMAKER_ENDPOINT",
+    "SNS_TOPIC",
+    "SQS_QUEUE",
+    "STEP_FUNCTIONS_ACTIVITY",
+    "STEP_FUNCTIONS_STATE_MACHINE",
+]
 SearchInsightsPaginatorName = Literal["search_insights"]
 SearchOrganizationInsightsPaginatorName = Literal["search_organization_insights"]
 ServiceNameType = Literal[
@@ -194,6 +226,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -235,7 +268,9 @@ ServiceName = Literal[
     "connect",
     "connect-contact-lens",
     "connectcampaigns",
+    "connectcases",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -313,6 +348,7 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
@@ -339,6 +375,7 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-user-subscriptions",
     "lightsail",
     "location",
     "logs",
@@ -367,6 +404,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
@@ -392,6 +430,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
@@ -454,6 +493,7 @@ ServiceName = Literal[
     "storagegateway",
     "sts",
     "support",
+    "support-app",
     "swf",
     "synthetics",
     "textract",
@@ -506,12 +546,19 @@ PaginatorName = Literal[
 ]
 RegionName = Literal[
     "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-south-1",
     "ap-southeast-1",
     "ap-southeast-2",
+    "ca-central-1",
     "eu-central-1",
     "eu-north-1",
     "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "sa-east-1",
     "us-east-1",
     "us-east-2",
+    "us-west-1",
     "us-west-2",
 ]
