@@ -260,7 +260,7 @@ class ListMonitoredResourcesPaginator(Paginator):
     def paginate(
         self,
         *,
-        Filters: ListMonitoredResourcesFiltersTypeDef,
+        Filters: ListMonitoredResourcesFiltersTypeDef = ...,
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListMonitoredResourcesResponseTypeDef]:
         """
