@@ -32,18 +32,16 @@ from .literals import (
     InsightTypeType,
     LocaleType,
     LogAnomalyTypeType,
+    NotificationMessageTypeType,
     OptInStatusType,
     OrganizationResourceCollectionTypeType,
     ResourceCollectionTypeType,
     ResourcePermissionType,
+    ResourceTypeFilterType,
     ServiceNameType,
     UpdateResourceCollectionActionType,
 )
 
-if sys.version_info >= (3, 9):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -88,12 +86,12 @@ __all__ = (
     "ListAnomalousLogGroupsRequestRequestTypeDef",
     "ListInsightsOngoingStatusFilterTypeDef",
     "ListMonitoredResourcesFiltersTypeDef",
-    "MonitoredResourceIdentifierTypeDef",
     "ListNotificationChannelsRequestRequestTypeDef",
     "ListRecommendationsRequestRequestTypeDef",
     "LogAnomalyClassTypeDef",
     "LogsAnomalyDetectionIntegrationConfigTypeDef",
     "LogsAnomalyDetectionIntegrationTypeDef",
+    "NotificationFilterConfigTypeDef",
     "SnsChannelConfigTypeDef",
     "OpsCenterIntegrationConfigTypeDef",
     "OpsCenterIntegrationTypeDef",
@@ -137,7 +135,6 @@ __all__ = (
     "ListInsightsAnyStatusFilterTypeDef",
     "ListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef",
     "ListMonitoredResourcesRequestRequestTypeDef",
-    "ListMonitoredResourcesResponseTypeDef",
     "LogAnomalyShowcaseTypeDef",
     "NotificationChannelConfigTypeDef",
     "UpdateServiceIntegrationConfigTypeDef",
@@ -165,6 +162,7 @@ __all__ = (
     "GetResourceCollectionResponseTypeDef",
     "EventTypeDef",
     "ListEventsFiltersTypeDef",
+    "MonitoredResourceIdentifierTypeDef",
     "ProactiveInsightSummaryTypeDef",
     "ProactiveInsightTypeDef",
     "ProactiveOrganizationInsightSummaryTypeDef",
@@ -187,6 +185,7 @@ __all__ = (
     "ListEventsResponseTypeDef",
     "ListEventsRequestListEventsPaginateTypeDef",
     "ListEventsRequestRequestTypeDef",
+    "ListMonitoredResourcesResponseTypeDef",
     "ListInsightsResponseTypeDef",
     "SearchInsightsResponseTypeDef",
     "SearchOrganizationInsightsResponseTypeDef",
@@ -673,20 +672,10 @@ ListMonitoredResourcesFiltersTypeDef = TypedDict(
     "ListMonitoredResourcesFiltersTypeDef",
     {
         "ResourcePermission": ResourcePermissionType,
-        "ResourceTypeFilters": Sequence[Literal["LOG_GROUPS"]],
+        "ResourceTypeFilters": Sequence[ResourceTypeFilterType],
     },
 )
 
-MonitoredResourceIdentifierTypeDef = TypedDict(
-    "MonitoredResourceIdentifierTypeDef",
-    {
-        "MonitoredResourceName": str,
-        "Type": str,
-        "ResourcePermission": ResourcePermissionType,
-    },
-    total=False,
-)
-
 ListNotificationChannelsRequestRequestTypeDef = TypedDict(
     "ListNotificationChannelsRequestRequestTypeDef",
     {
@@ -749,6 +738,15 @@ LogsAnomalyDetectionIntegrationTypeDef = TypedDict(
     total=False,
 )
 
+NotificationFilterConfigTypeDef = TypedDict(
+    "NotificationFilterConfigTypeDef",
+    {
+        "Severities": Sequence[InsightSeverityType],
+        "MessageTypes": Sequence[NotificationMessageTypeType],
+    },
+    total=False,
+)
+
 SnsChannelConfigTypeDef = TypedDict(
     "SnsChannelConfigTypeDef",
     {
@@ -928,6 +926,7 @@ DescribeAccountHealthResponseTypeDef = TypedDict(
         "OpenProactiveInsights": int,
         "MetricsAnalyzed": int,
         "ResourceHours": int,
+        "AnalyzedResourceCount": int,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -975,6 +974,7 @@ CloudFormationHealthTypeDef = TypedDict(
     {
         "StackName": str,
         "Insight": InsightHealthTypeDef,
+        "AnalyzedResourceCount": int,
     },
     total=False,
 )
@@ -985,6 +985,7 @@ TagHealthTypeDef = TypedDict(
         "AppBoundaryKey": str,
         "TagValue": str,
         "Insight": InsightHealthTypeDef,
+        "AnalyzedResourceCount": int,
     },
     total=False,
 )
@@ -1219,60 +1220,25 @@ ListInsightsAnyStatusFilterTypeDef = TypedDict(
     },
 )
 
-_RequiredListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef = TypedDict(
-    "_RequiredListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef",
+ListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef = TypedDict(
+    "ListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef",
     {
         "Filters": ListMonitoredResourcesFiltersTypeDef,
-    },
-)
-_OptionalListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef = TypedDict(
-    "_OptionalListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef",
-    {
         "PaginationConfig": PaginatorConfigTypeDef,
     },
     total=False,
 )
 
-
-class ListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef(
-    _RequiredListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef,
-    _OptionalListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef,
-):
-    pass
-
-
-_RequiredListMonitoredResourcesRequestRequestTypeDef = TypedDict(
-    "_RequiredListMonitoredResourcesRequestRequestTypeDef",
+ListMonitoredResourcesRequestRequestTypeDef = TypedDict(
+    "ListMonitoredResourcesRequestRequestTypeDef",
     {
         "Filters": ListMonitoredResourcesFiltersTypeDef,
-    },
-)
-_OptionalListMonitoredResourcesRequestRequestTypeDef = TypedDict(
-    "_OptionalListMonitoredResourcesRequestRequestTypeDef",
-    {
         "MaxResults": int,
         "NextToken": str,
     },
     total=False,
 )
 
-
-class ListMonitoredResourcesRequestRequestTypeDef(
-    _RequiredListMonitoredResourcesRequestRequestTypeDef,
-    _OptionalListMonitoredResourcesRequestRequestTypeDef,
-):
-    pass
-
-
-ListMonitoredResourcesResponseTypeDef = TypedDict(
-    "ListMonitoredResourcesResponseTypeDef",
-    {
-        "MonitoredResourceIdentifiers": List[MonitoredResourceIdentifierTypeDef],
-        "NextToken": str,
-        "ResponseMetadata": ResponseMetadataTypeDef,
-    },
-)
-
 LogAnomalyShowcaseTypeDef = TypedDict(
     "LogAnomalyShowcaseTypeDef",
     {
@@ -1281,12 +1247,26 @@ LogAnomalyShowcaseTypeDef = TypedDict(
     total=False,
 )
 
-NotificationChannelConfigTypeDef = TypedDict(
-    "NotificationChannelConfigTypeDef",
+_RequiredNotificationChannelConfigTypeDef = TypedDict(
+    "_RequiredNotificationChannelConfigTypeDef",
     {
         "Sns": SnsChannelConfigTypeDef,
     },
 )
+_OptionalNotificationChannelConfigTypeDef = TypedDict(
+    "_OptionalNotificationChannelConfigTypeDef",
+    {
+        "Filters": NotificationFilterConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class NotificationChannelConfigTypeDef(
+    _RequiredNotificationChannelConfigTypeDef, _OptionalNotificationChannelConfigTypeDef
+):
+    pass
+
 
 UpdateServiceIntegrationConfigTypeDef = TypedDict(
     "UpdateServiceIntegrationConfigTypeDef",
@@ -1356,6 +1336,7 @@ ServiceHealthTypeDef = TypedDict(
     {
         "ServiceName": ServiceNameType,
         "Insight": ServiceInsightHealthTypeDef,
+        "AnalyzedResourceCount": int,
     },
     total=False,
 )
@@ -1542,6 +1523,18 @@ ListEventsFiltersTypeDef = TypedDict(
     total=False,
 )
 
+MonitoredResourceIdentifierTypeDef = TypedDict(
+    "MonitoredResourceIdentifierTypeDef",
+    {
+        "MonitoredResourceName": str,
+        "Type": str,
+        "ResourcePermission": ResourcePermissionType,
+        "LastUpdated": datetime,
+        "ResourceCollection": ResourceCollectionTypeDef,
+    },
+    total=False,
+)
+
 ProactiveInsightSummaryTypeDef = TypedDict(
     "ProactiveInsightSummaryTypeDef",
     {
@@ -1880,6 +1873,15 @@ class ListEventsRequestRequestTypeDef(
     pass
 
 
+ListMonitoredResourcesResponseTypeDef = TypedDict(
+    "ListMonitoredResourcesResponseTypeDef",
+    {
+        "MonitoredResourceIdentifiers": List[MonitoredResourceIdentifierTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ListInsightsResponseTypeDef = TypedDict(
     "ListInsightsResponseTypeDef",
     {
